==> react-collapsible-readmore-1.4.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Chevronbottom from '@s-ui/react-icons/lib/Chevronbottom';
var CLASS = 'sui-CollapsibleReadmore';

var NO_OP = function NO_OP() {};

var CollapsibleReadmore =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(CollapsibleReadmore, _Component);

  function CollapsibleReadmore() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      collapsed: false
    };
    _this._readMoreContentRef = React.createRef();
    _this._readMoreButtonEnabled = false;
    _this._fullContentHeight = null;

    _this._handleEllipsisClick = function (event) {
      event.stopPropagation();

      _this.props.onEllipsisClick({
        collapsed: !_this.state.collapsed
      });

      _this._toggle();
    };

    return _this;
  }

  var _proto = CollapsibleReadmore.prototype;

  _proto._getContentWrapperClassNames = function _getContentWrapperClassNames() {
    var _cx;

    return cx(CLASS + "-contentWrapper", (_cx = {}, _cx[CLASS + "-gradient"] = this.props.gradient, _cx));
  };

  _proto._getContentWrapperInlineStyles = function _getContentWrapperInlineStyles() {
    return {
      maxHeight: this.state.collapsed ? this.props.maxHeight : this._fullContentHeight
    };
  };

  _proto._toggle = function _toggle() {
    this.setState(function (prevState) {
      return {
        collapsed: !prevState.collapsed
      };
    });
  };

  _proto._renderEllipsis = function _renderEllipsis() {
    var _this$props = this.props,
        _this$props$ellipsis = _this$props.ellipsis,
        EllipsisIcon = _this$props$ellipsis.icon,
        size = _this$props$ellipsis.size,
        ellipsisText = _this$props.ellipsisText;
    return React.createElement("a", {
      className: CLASS + "-ellipsisLink",
      onClick: this._handleEllipsisClick,
      role: "button"
    }, React.createElement("div", {
      className: CLASS + "-ellipsisWrapper"
    }, React.createElement("span", {
      className: CLASS + "-ellipsisText"
    }, this.state.collapsed ? ellipsisText.collapsed : ellipsisText.expanded), React.createElement("div", {
      className: CLASS + "-ellipsisIconBox"
    }, EllipsisIcon && React.createElement(EllipsisIcon, {
      className: CLASS + "-ellipsisIcon",
      size: size,
      svgClass: CLASS + "-ellipsisIcon"
    }))));
  };

  _proto.componentDidMount = function componentDidMount() {
    var contentWrapperEl = this._readMoreContentRef.current;
    this._fullContentHeight = contentWrapperEl ? contentWrapperEl.offsetHeight : 0;

    if (this._fullContentHeight > this.props.maxHeight) {
      this._readMoreButtonEnabled = true;

      this._toggle();
    }
  };

  _proto.render = function render() {
    var children = this.props.children;
    return React.createElement("div", {
      className: cx(CLASS, {
        'is-expanded': !this.state.collapsed
      })
    }, React.createElement("div", {
      className: this._getContentWrapperClassNames(),
      ref: this._readMoreContentRef,
      style: this._getContentWrapperInlineStyles()
    }, children), this._readMoreButtonEnabled && this._renderEllipsis());
  };

  return CollapsibleReadmore;
}(Component);

CollapsibleReadmore.defaultProps = {
  ellipsis: {
    icon: Chevronbottom,
    size: 16
  },
  onEllipsisClick: NO_OP
};
CollapsibleReadmore.displayName = 'CollapsibleReadmore';
export { CollapsibleReadmore as default };

==> react-collapsible-readmore-1.6.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { createRef, Component } from 'react';
import cx from 'classnames';
import Chevronbottom from '@s-ui/react-icons/lib/Chevronbottom';
var CLASS = 'sui-CollapsibleReadmore';

var NO_OP = function NO_OP() {};

var CollapsibleReadmore = /*#__PURE__*/function (_Component) {
  _inheritsLoose(CollapsibleReadmore, _Component);

  function CollapsibleReadmore() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      collapsed: false
    };
    _this._readMoreContentRef = /*#__PURE__*/createRef();
    _this._readMoreButtonEnabled = false;
    _this._fullContentHeight = null;

    _this._handleEllipsisClick = function (event) {
      event.stopPropagation();

      _this.props.onEllipsisClick({
        collapsed: !_this.state.collapsed
      });

      _this._toggle();
    };

    return _this;
  }

  var _proto = CollapsibleReadmore.prototype;

  _proto._getContentWrapperClassNames = function _getContentWrapperClassNames() {
    var _cx;

    return cx(CLASS + "-contentWrapper", (_cx = {}, _cx[CLASS + "-gradient"] = this.props.gradient, _cx));
  };

  _proto._getContentWrapperInlineStyles = function _getContentWrapperInlineStyles() {
    return {
      maxHeight: this.state.collapsed ? this.props.maxHeight : this._fullContentHeight
    };
  };

  _proto._toggle = function _toggle() {
    this.setState(function (prevState) {
      return {
        collapsed: !prevState.collapsed
      };
    });
  };

  _proto._renderEllipsis = function _renderEllipsis() {
    var _this$props = this.props,
        _this$props$ellipsis = _this$props.ellipsis,
        EllipsisIcon = _this$props$ellipsis.icon,
        size = _this$props$ellipsis.size,
        ellipsisText = _this$props.ellipsisText;
    return /*#__PURE__*/_jsx("a", {
      className: CLASS + "-ellipsisLink",
      onClick: this._handleEllipsisClick,
      role: "button",
      children: /*#__PURE__*/_jsxs("div", {
        className: CLASS + "-ellipsisWrapper",
        children: [/*#__PURE__*/_jsx("span", {
          className: CLASS + "-ellipsisText",
          children: this.state.collapsed ? ellipsisText.collapsed : ellipsisText.expanded
        }), /*#__PURE__*/_jsx("div", {
          className: CLASS + "-ellipsisIconBox",
          children: EllipsisIcon && /*#__PURE__*/_jsx(EllipsisIcon, {
            className: CLASS + "-ellipsisIcon",
            size: size,
            svgClass: CLASS + "-ellipsisIcon"
          })
        })]
      })
    });
  };

  _proto.componentDidMount = function componentDidMount() {
    var contentWrapperEl = this._readMoreContentRef.current;
    this._fullContentHeight = contentWrapperEl ? contentWrapperEl.offsetHeight : 0;

    if (this._fullContentHeight > this.props.maxHeight) {
      this._readMoreButtonEnabled = true;

      this._toggle();
    }
  };

  _proto.render = function render() {
    var children = this.props.children;
    return /*#__PURE__*/_jsxs("div", {
      className: cx(CLASS, {
        'is-expanded': !this.state.collapsed
      }),
      children: [/*#__PURE__*/_jsx("div", {
        className: this._getContentWrapperClassNames(),
        ref: this._readMoreContentRef,
        style: this._getContentWrapperInlineStyles(),
        children: children
      }), this._readMoreButtonEnabled && this._renderEllipsis()]
    });
  };

  return CollapsibleReadmore;
}(Component);

CollapsibleReadmore.defaultProps = {
  ellipsis: {
    icon: Chevronbottom,
    size: 16
  },
  onEllipsisClick: NO_OP
};
CollapsibleReadmore.displayName = 'CollapsibleReadmore';
export { CollapsibleReadmore as default };
